searchData={"items":[{"type":"module","title":"CLIX","doc":"A utility-first, composable CLI framework.\n\nBefore we begin, let's first talk about the terminology and conventions used\nin CLIX.","ref":"CLIX.html"},{"type":"module","title":"The flow of CLIX - CLIX","doc":"1. use `CLIX.Spec` to build a spec.\n  2. use `CLIX.Parser` to parse argv with the built spec.\n  3. use `CLIX.Feedback` to generate user-faced feedbacks with the built spec.","ref":"CLIX.html#module-the-flow-of-clix"},{"type":"module","title":"About arguments - CLIX","doc":"The arguments is the abbrev of \"command line arguments\", which is the main\nthing handled by a CLI framework.","ref":"CLIX.html#module-about-arguments"},{"type":"module","title":"Positional arguments - CLIX","doc":"In general, positional arguments are the ones which are not prefixed with\n`-` or `--`.\n\n> Negative number(like `-3`, `-3.14`) is a special case, but CLIX's parser\n> can handle it properly.","ref":"CLIX.html#module-positional-arguments"},{"type":"module","title":"Optional arguments - CLIX","doc":"In general, optional arguments are the ones prefixed with `-` or `--`:\n\n  * POSIX syntax - `-` followed by a single letter indicating an option.\n  * GNU-extended syntax - `--` followed by a long name indicating an option.\n\n> CLIX doesn't plan to support special prefixes, such as `/` or `+`, so we\n> ignore them.\n\nIn practice, optional arguments are often used to implement options. For\noptions, there is a further level of classification:\n\n  * options which require subsequent arguments, such as `-o value` or `--option value`.\n  * options which don't require subsequent arguments, such as `-o` or `--option`.\n    They are commonly referred to as flags, because they represent boolean states.\n\n> CLIX doesn't explicitly distinguish between flags and options, as a flag is\n> simply a special type of option.\n\n#### Option terminator\n\nThe option terminator is `--`. When it is used, all the arguments after it are\nconsidered as positional arguments.","ref":"CLIX.html#module-optional-arguments"},{"type":"module","title":"The optionality of arguments - CLIX","doc":"In CLIX, we think:\n\n  * positional arguments are required by default, but can be made optional.\n  * optional arguments are always optional, and this is unchangeable.\n\nIn other implementations, optional arguments can be made required. Personally,\nI don't think that's a good design. You can try to say \"The optional argument\nis required\", then you might feel it's a bit counterintuitive. That's because\nthe name (optional argument) does not match its description (requried).","ref":"CLIX.html#module-the-optionality-of-arguments"},{"type":"module","title":"Conventions - CLIX","doc":"","ref":"CLIX.html#module-conventions"},{"type":"module","title":"Abbreviations - CLIX","doc":"To make the code or doc more compact, we use some abbreviations to describe\npositional arguments and optional arguments.\n\nAt the implementation level, which the CLIX's developers should care about:\n\n  * `pos_args` - refers to positional arguments\n  * `opt_args` - refers to optional arguments\n\nAt the interface level, which the CLIX's users should care about:\n\n  * `args` - refers to positional arguments\n  * `opts` - refers to optional arguments\n\nAnd, when you see a standalone \"arguments\", it means arguments in the general sense.","ref":"CLIX.html#module-abbreviations"},{"type":"module","title":"The structure of an option - CLIX","doc":"|                    | option prefix | option string    | option name | option value |\n| ------------------ | ------------- | ---------------- | ----------- | ------------ |\n| `-o  `       | `-`           | `o`              | `o`         | ` `    |\n| `-o `        | `-`           | `o `       | `o`         | ` `    |\n| `--option  ` | `--`          | `option`         | `option`    | ` `    |\n| `--option= ` | `--`          | `option= ` | `option`    | ` `    |\n\n> This is a convention used in CLIX, not a standard widely accepted.","ref":"CLIX.html#module-the-structure-of-an-option"},{"type":"module","title":"CLIX.Feedback","doc":"The feedback generator.\n\nIt's designed to generate clear and compact feedbacks.","ref":"CLIX.Feedback.html"},{"type":"module","title":"Quick start - CLIX.Feedback","doc":"iex> # 1. build a spec\n    iex> spec =\n    iex>   CLIX.Spec.new(\n    iex>     {:calc,\n    iex>      %{\n    iex>        summary: \"A simple calculator.\",\n    iex>        description: \"\"\"\n    iex>        This calculator is for demostrating the funtionality of `CLIX.Feedback`.\n    iex>        You can copy and play with it.\n    iex>        \"\"\",\n    iex>        cmds: [\n    iex>          add: %{\n    iex>            summary: \"Add two number.\",\n    iex>            help: \"add two number\",\n    iex>            args: [\n    iex>              left: %{type: :integer, help: \"the left number\"},\n    iex>              right: %{type: :integer, help: \"the right number\"}\n    iex>            ]\n    iex>          },\n    iex>          minus: %{\n    iex>            summary: \"Minus two number.\",\n    iex>            help: \"minus two number\",\n    iex>            args: [\n    iex>              left: %{type: :integer, help: \"the left number\"},\n    iex>              right: %{type: :integer, help: \"the right number\"}\n    iex>            ]\n    iex>          }\n    iex>        ],\n    iex>        opts: [\n    iex>          debug: %{\n    iex>            short: \"d\",\n    iex>            long: \"debug\",\n    iex>            type: :boolean,\n    iex>            help: \"enable debug logging\"\n    iex>          },\n    iex>          verbose: %{\n    iex>            short: \"v\",\n    iex>            long: \"verbose\",\n    iex>            type: :boolean,\n    iex>            action: :count,\n    iex>            help: \"specify verbose level\"\n    iex>          }\n    iex>        ],\n    iex>        epilogue: \"\"\"\n    iex>        For more help on how to use CLIX, head to https://hex.pm/packages/clix\n    iex>        \"\"\"\n    iex>      }}\n    iex>    )\n    iex>\n    iex> # 2. generate doc\n    iex>\n    iex> # for root command\n    iex> CLIX.Feedback.help(spec)\n    iex>\n    iex> # for sub-command - add\n    iex> CLIX.Feedback.help(spec, [:add])\n    iex>\n    iex> # for sub-command - minus\n    iex> CLIX.Feedback.help(spec, [:minus])\n\nThe output:\n\n<!-- tabs-open -->","ref":"CLIX.Feedback.html#module-quick-start"},{"type":"module","title":"root command - CLIX.Feedback","doc":"```console\nA simple calculator.\n\nThis calculator is for demostrating the funtionality of `CLIX.Feedback`.\nYou can copy and play with it.\n\nUsage:\n  calc   [OPTIONS]\n\nCommands:\n  add    add two number\n  minus  minus two number\n\nOptions:\n  -d, --debug       enable debug logging\n  -v, --verbose...  specify verbose level\n\nFor more help on how to use CLIX, head to https://hex.pm/packages/clix\n```","ref":"CLIX.Feedback.html#module-root-command"},{"type":"module","title":"sub-command `add` - CLIX.Feedback","doc":"```console\nAdd two number.\n\nUsage:\n  calc add [OPTIONS]    \n\nArguments:\n      the left number\n     the right number\n\nOptions:\n  -d, --debug       enable debug logging\n  -v, --verbose...  specify verbose level\n```","ref":"CLIX.Feedback.html#module-sub-command-add"},{"type":"module","title":"sub-command `minus` - CLIX.Feedback","doc":"```console\nMinus two number.\n\nUsage:\n  calc minus [OPTIONS]    \n\nArguments:\n      the left number\n     the right number\n\nOptions:\n  -d, --debug       enable debug logging\n  -v, --verbose...  specify verbose level\n```\n\n<!-- tabs-close -->","ref":"CLIX.Feedback.html#module-sub-command-minus"},{"type":"function","title":"CLIX.Feedback.format_error/1","doc":"Formats a parsing error.","ref":"CLIX.Feedback.html#format_error/1"},{"type":"function","title":"CLIX.Feedback.help/2","doc":"Generates comprehensive help.\n\nThe structure of generated content:\n\n```plain\n[summary]\n\n[description]\n\n[usage]\n\n[sub-commands]\n\n[positional arguments]\n\n[optional arguments]\n\n[epilogue]\n```","ref":"CLIX.Feedback.html#help/2"},{"type":"type","title":"CLIX.Feedback.subcmd_path/0","doc":"","ref":"CLIX.Feedback.html#t:subcmd_path/0"},{"type":"module","title":"CLIX.Parser","doc":"The command line arguments parser.\n\nIt designed to:\n\n  * parse both sub-commands, positional arguments, and optional arguments\n  * pepare read-to-use result","ref":"CLIX.Parser.html"},{"type":"module","title":"Quick start - CLIX.Parser","doc":"iex> # 1. build a spec\n    iex> spec = CLIX.Spec.new({:hello, %{\n    iex>   args: [\n    iex>     msg: %{}\n    iex>   ],\n    iex>   opts: [\n    iex>     debug: %{short: \"d\", long: \"debug\", type: :boolean},\n    iex>     verbose: %{short: \"v\", long: \"verbose\", type: :boolean, action: :count},\n    iex>     to: %{short: \"t\", long: \"to\", type: :string, action: :append}\n    iex>   ]\n    iex> }})\n    iex>\n    iex> # 2. parse argv with spec\n    iex>\n    iex> # bad argv\n    iex> CLIX.Parser.parse(spec, [])\n    {[], %{}, %{debug: false, verbose: 0, to: []}, [\n      {:missing_arg, %{message: nil, type: :string, value: nil, value_name: \"MSG\", nargs: nil}}\n    ]}\n    iex>\n    iex> # good argv in strict order\n    iex> CLIX.Parser.parse(spec, [\"--debug\", \"-vvvv\", \"-t\", \"John\", \"-t\", \"Dave\", \"aloha\"])\n    {[], %{msg: \"aloha\"}, %{debug: true, to: [\"John\", \"Dave\"], verbose: 4}, []}\n    iex>\n    iex> # good argv in intermixed order\n    iex> CLIX.Parser.parse(spec, [\"--debug\", \"-vvvv\", \"aloha\", \"-t\", \"John\", \"-t\", \"Dave\", ])\n    {[], %{msg: \"aloha\"}, %{debug: true, to: [\"John\", \"Dave\"], verbose: 4}, []}\n\nRead the doc of `CLIX.Spec` and `CLIX.Parser` for more information.","ref":"CLIX.Parser.html#module-quick-start"},{"type":"module","title":"The parsing of sub-commands - CLIX.Parser","doc":"A sub-command always takes precedence over arguments. It means that a subcommand\nshould always placed after the root command.\n\nAn example cloning `kamal`, which demostrates nested sub-commands, global options, etc.\n\n    iex> # 1. build a spec\n    iex> spec = CLIX.Spec.new({:kamal, %{\n    iex>   cmds: [\n    iex>     setup: %{\n    iex>       help: \"Setup all accessories, push the env, and deploy app to servers\",\n    iex>       opts: [\n    iex>         skip_push: %{\n    iex>           short: \"P\",\n    iex>           long: \"skip-push\",\n    iex>           type: :boolean,\n    iex>           help: \"Skip image build and push\"\n    iex>         }\n    iex>       ]\n    iex>     },\n    iex>     app: %{\n    iex>       help: \"Manage application\",\n    iex>       cmds: %{\n    iex>         boot: %{\n    iex>           help: \"Boot app on servers (or reboot app if already running)\",\n    iex>         },\n    iex>         containers: %{\n    iex>           help: \"Show app containers on servers\"\n    iex>         }\n    iex>       }\n    iex>     }\n    iex>   ],\n    iex>   opts: [\n    iex>     verbose: %{\n    iex>       short: \"v\",\n    iex>       long: \"verbose\",\n    iex>       type: :boolean,\n    iex>       action: :count,\n    iex>       help: \"Detailed logging\"\n    iex>     },\n    iex>     quiet: %{\n    iex>       short: \"q\",\n    iex>       long: \"quiet\",\n    iex>       type: :boolean,\n    iex>       help: \"Minimal logging\"\n    iex>     }\n    iex>   ]\n    iex> }})\n    iex>\n    iex> # 2. parse argv with spec\n    iex>\n    iex> # root command\n    iex> CLIX.Parser.parse(spec, [])\n    {[], %{}, %{verbose: 0, quiet: false}, []}\n    iex>\n    iex> # sub-command - setup\n    iex> CLIX.Parser.parse(spec, [\"setup\", \"-P\"])\n    {[:setup], %{}, %{verbose: 0, quiet: false, skip_push: true}, []}\n    iex>\n    iex> # sub-command - app\n    iex> CLIX.Parser.parse(spec, [\"app\"])\n    {[:app], %{}, %{verbose: 0, quiet: false}, []}\n    iex>\n    iex> # nested sub-command - app boot\n    iex> CLIX.Parser.parse(spec, [\"app\", \"boot\"])\n    {[:app, :boot], %{}, %{verbose: 0, quiet: false}, []}\n    iex>\n    iex> # nested sub-command - app containers\n    iex> CLIX.Parser.parse(spec, [\"app\", \"containers\"])\n    {[:app, :containers], %{}, %{verbose: 0, quiet: false}, []}","ref":"CLIX.Parser.html#module-the-parsing-of-sub-commands"},{"type":"module","title":"The parsing of positional arguments - CLIX.Parser","doc":"The key part here is how to allocate a limited number of arguments to as many\ndifferent positional arguments as possible. With the design of `t:CLIX.Spec.nargs/0`,\nwe can easily achieve it.\n\nAn example cloning `cp` (`cp  ...  `):\n\n    iex> spec = CLIX.Spec.new({:cp, %{args: [\n    iex>   src: %{nargs: :+},\n    iex>   dst: %{}\n    iex> ]}})\n    iex>\n    iex> CLIX.Parser.parse(spec, [])\n    {[], %{}, %{}, [\n      {:missing_arg, %{message: nil, type: :string, value: nil, nargs: :+, value_name: \"SRC\"}},\n      {:missing_arg, %{message: nil, type: :string, value: nil, nargs: nil, value_name: \"DST\"}}\n    ]}\n    iex>\n    iex> CLIX.Parser.parse(spec, [\"src1\"])\n    {[], %{src: [\"src1\"]}, %{}, [\n      {:missing_arg, %{message: nil, type: :string, value: nil, nargs: nil, value_name: \"DST\"}}\n    ]}\n    iex>\n    iex> CLIX.Parser.parse(spec, [\"src1\", \"dst\"])\n    {[], %{src: [\"src1\"], dst: \"dst\"}, %{}, []}\n    iex>\n    iex> CLIX.Parser.parse(spec, [\"src1\", \"src2\", \"dst\"])\n    {[], %{src: [\"src1\", \"src2\"], dst: \"dst\"}, %{}, []}\n\nOr, an example cloning `httpie` (`httpie [METHOD]   [REQUEST_ITEM]`):\n\n    iex> spec = CLIX.Spec.new({:httpie, %{args: [\n    iex>   method: %{nargs: :\"?\", default: \"GET\"},\n    iex>   url: %{},\n    iex>   request_items: %{nargs: :*}\n    iex> ]}})\n    iex>\n    iex> CLIX.Parser.parse(spec, [\"https://example.com\"])\n    {[], %{method: \"GET\", url: \"https://example.com\", request_items: []}, %{}, []}\n    iex>\n    iex> CLIX.Parser.parse(spec, [\"POST\", \"https://example.com\"])\n    {[], %{method: \"POST\", url: \"https://example.com\", request_items: []}, %{}, []}\n    iex>\n    iex> CLIX.Parser.parse(spec, [\"POST\", \"https://example.com\", \"name=Joe\", \"email=Joe@example.com\"])\n    {[], %{method: \"POST\", url: \"https://example.com\", request_items: [\"name=Joe\", \"email=Joe@example.com\"]}, %{}, []}\n\n> The algo is borrowed from\n> Python's [argparse](https://github.com/python/cpython/blob/3.13/Lib/argparse.py).","ref":"CLIX.Parser.html#module-the-parsing-of-positional-arguments"},{"type":"module","title":"The parsing of optional arguments - CLIX.Parser","doc":"","ref":"CLIX.Parser.html#module-the-parsing-of-optional-arguments"},{"type":"module","title":"Supported syntax - CLIX.Parser","doc":"The syntax of GNU's getopt (implicitly involves POSIX's getopt) is supported.\n\n```plain\n# short opts\n-f\n-o  \n-o      # equals to -o  \n-abc          # equals to -a -b -c\n-abco   # equals to -a -b -c -o  \n\n# long opts\n--flag\n--option  \n--option= \n```","ref":"CLIX.Parser.html#module-supported-syntax"},{"type":"module","title":"The parsing modes - CLIX.Parser","doc":"### `:intermixed` mode\n\nThis's the GNU's way of parsing optional arguments.\nThe positional arguments and optional arguments can be intermixed.\n\nFor example:\n\n```console\nprogram arg1 -f arg2 -o value arg3\n# equals to 'program -f -o value arg1 arg2 arg3'\n```\n\n### `:strict` mode\n\nThis's the POSIX's way of parsing optional arguments:\n\n  * requires all optional arguments to appear before positional arguments.\n  * any optional arguments after the first positional arguments are treated\n    as positiontal arguments.\n\n> It equals to set `POSIXLY_CORRECT` env for GNU's getopt.\n\nFor example:\n\n```console\nprogram -f -o value arg1 arg2 arg3\n\nprogram -f arg1 -o value arg2 arg3\n# equals to 'program -f -- arg1 -o value arg2 arg3'\n```","ref":"CLIX.Parser.html#module-the-parsing-modes"},{"type":"module","title":"About the internal - CLIX.Parser","doc":"It would be helpful to give you (the possible contributor) some information about the internal.","ref":"CLIX.Parser.html#module-about-the-internal"},{"type":"module","title":"Overview - CLIX.Parser","doc":"When parsing command line arguments, it processes them in multiple stages.\n\n  * stage 0 - parse sub-commands.\n  * stage 1 - parse optional arguments and collecting positional arguments.\n  * stage 2 - parse positional arguments.","ref":"CLIX.Parser.html#module-overview"},{"type":"module","title":"Variable names - CLIX.Parser","doc":"* For argument specs, use `pos_specs`, `opt_specs`.\n  * For raw arguments, use `pos_argv`, `opt_argv`.\n  * For parsed arguments, use `pos_args`, `opt_args`.","ref":"CLIX.Parser.html#module-variable-names"},{"type":"module","title":"Verify compatibility with GNU's getopt - CLIX.Parser","doc":"I'm using [jamesodhunt/test-getopt](https://github.com/jamesodhunt/test-getopt).","ref":"CLIX.Parser.html#module-verify-compatibility-with-gnu-s-getopt"},{"type":"function","title":"CLIX.Parser.parse/3","doc":"Parses `argv` with given `spec`.\n\nAvailable opts:\n\n  * `:mode` - `:intermixed` (default) / `:strict`","ref":"CLIX.Parser.html#parse/3"},{"type":"type","title":"CLIX.Parser.arg_error_detail/0","doc":"","ref":"CLIX.Parser.html#t:arg_error_detail/0"},{"type":"type","title":"CLIX.Parser.argv/0","doc":"The list of command line arguments to be parsed.\n\nIn general, it's obtained by calling `System.argv/0`.","ref":"CLIX.Parser.html#t:argv/0"},{"type":"type","title":"CLIX.Parser.error/0","doc":"","ref":"CLIX.Parser.html#t:error/0"},{"type":"type","title":"CLIX.Parser.errors/0","doc":"The errors of parsing.","ref":"CLIX.Parser.html#t:errors/0"},{"type":"type","title":"CLIX.Parser.opt/0","doc":"","ref":"CLIX.Parser.html#t:opt/0"},{"type":"type","title":"CLIX.Parser.opt_error_detail/0","doc":"","ref":"CLIX.Parser.html#t:opt_error_detail/0"},{"type":"type","title":"CLIX.Parser.opts/0","doc":"The options of parsing.","ref":"CLIX.Parser.html#t:opts/0"},{"type":"type","title":"CLIX.Parser.parsed_args/0","doc":"","ref":"CLIX.Parser.html#t:parsed_args/0"},{"type":"type","title":"CLIX.Parser.parsed_opts/0","doc":"","ref":"CLIX.Parser.html#t:parsed_opts/0"},{"type":"type","title":"CLIX.Parser.raw_arg/0","doc":"A raw command line argument.","ref":"CLIX.Parser.html#t:raw_arg/0"},{"type":"type","title":"CLIX.Parser.result/0","doc":"The result of parsing.","ref":"CLIX.Parser.html#t:result/0"},{"type":"type","title":"CLIX.Parser.subcmd_path/0","doc":"","ref":"CLIX.Parser.html#t:subcmd_path/0"},{"type":"module","title":"CLIX.Spec","doc":"The spec builder.\n\nA spec is the basis for parsing, feedback generation, etc.","ref":"CLIX.Spec.html"},{"type":"function","title":"CLIX.Spec.new/1","doc":"Builds a spec from raw spec.\n\nIt will cast and validate the raw spec.","ref":"CLIX.Spec.html#new/1"},{"type":"type","title":"CLIX.Spec.action/0","doc":"","ref":"CLIX.Spec.html#t:action/0"},{"type":"type","title":"CLIX.Spec.arg_name/0","doc":"The name of a positional argument.","ref":"CLIX.Spec.html#t:arg_name/0"},{"type":"type","title":"CLIX.Spec.arg_spec/0","doc":"The parsing spec of positional argument.","ref":"CLIX.Spec.html#t:arg_spec/0"},{"type":"type","title":"CLIX.Spec.cmd_name/0","doc":"The name of a command.\n\nThe top-level cmd_name is the program name. If you name your CLI app as *example*,\nthen you should set the top-level cmd_name as `:example`.","ref":"CLIX.Spec.html#t:cmd_name/0"},{"type":"type","title":"CLIX.Spec.cmd_spec/0","doc":"The parsing spec of a command.\n\nIf the `:help` option isn't set, it will default to the value of `:summary`\noption.","ref":"CLIX.Spec.html#t:cmd_spec/0"},{"type":"type","title":"CLIX.Spec.custom_type/0","doc":"Custom type.","ref":"CLIX.Spec.html#t:custom_type/0"},{"type":"type","title":"CLIX.Spec.nargs/0","doc":"The number of arguments that should be consumed.\n\n  * `nil` - consume one argument.\n  * `:\"?\"` - consume zero or one argument.\n  * `:*` - consume zero or more arguments.\n  * `:+` - consume one or more arguments.","ref":"CLIX.Spec.html#t:nargs/0"},{"type":"type","title":"CLIX.Spec.opt_name/0","doc":"The name of an optional argument.","ref":"CLIX.Spec.html#t:opt_name/0"},{"type":"type","title":"CLIX.Spec.opt_spec/0","doc":"The parsing spec of optional argument.","ref":"CLIX.Spec.html#t:opt_spec/0"},{"type":"type","title":"CLIX.Spec.t/0","doc":"The spec.","ref":"CLIX.Spec.html#t:t/0"},{"type":"type","title":"CLIX.Spec.type/0","doc":"The type which the argument will be parsed as.","ref":"CLIX.Spec.html#t:type/0"},{"type":"type","title":"CLIX.Spec.value_name/0","doc":"","ref":"CLIX.Spec.html#t:value_name/0"},{"type":"extras","title":"CLIX","doc":"# CLIX\n\n[![CI](https://github.com/cozy-elixir/clix/actions/workflows/ci.yml/badge.svg)](https://github.com/cozy-elixir/clix/actions/workflows/ci.yml)\n[![Hex.pm](https://img.shields.io/hexpm/v/clix.svg)](https://hex.pm/packages/clix)\n\nA utility-first, composable CLI framework.","ref":"readme.html"},{"type":"extras","title":"Installation - CLIX","doc":"Add `:clix` to the list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:clix,  }\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - CLIX","doc":"For more information, see the [documentation](https://hexdocs.pm/clix).","ref":"readme.html#usage"},{"type":"extras","title":"License - CLIX","doc":"[Apache License 2.0](https://www.apache.org/licenses/LICENSE-2.0)","ref":"readme.html#license"},{"type":"extras","title":"Practices","doc":"# Practices","ref":"practices.html"},{"type":"extras","title":"Collect multiple values by optional arguments - Practices","doc":"You might have noticed that `t:CLIX.Spec.opt_spec/0` does not support `:nargs`.\nThis is intentional.\n\nIf you want to collect multiple values by optional arguments, try following\nworkarounds:\n\n- use a delimiter to seperate multiple values, like `pgrep` did - `ps -s 123,456 ...`.\n- repeat an option mulitple times, like `grep` did - `grep -e pattern1 -e pattern2 ...`.","ref":"practices.html#collect-multiple-values-by-optional-arguments"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.35.1"}}